@@ -16,7 +16,6 @@ package main
 import (
 	"time"
 
-	"github.com/go-kit/log/level"
 	"github.com/prometheus/client_golang/prometheus"
 
 	"github.com/prometheus-community/ipmi_exporter/freeipmi"
@@ -60,7 +59,7 @@ func (c SELEventsCollector) Cmd() string {
 
 func (c SELEventsCollector) Args() []string {
 	return []string{
-		"-Q",
+		"--quiet-cache",
 		"--comma-separated-output",
 		"--no-header-output",
 		"--sdr-cache-recreate",
@@ -75,7 +74,7 @@ func (c SELEventsCollector) Collect(result freeipmi.Result, ch chan<- prometheus
 
 	events, err := freeipmi.GetSELEvents(result)
 	if err != nil {
-		level.Error(logger).Log("msg", "Failed to collect SEL events", "target", targetName(target.host), "error", err)
+		logger.Error("Failed to collect SEL events", "target", targetName(target.host), "error", err)
 		return 0, err
 	}
 
@@ -89,11 +88,12 @@ func (c SELEventsCollector) Collect(result freeipmi.Result, ch chan<- prometheus
 		selEventByNameCount[metricConfig.Name] = 0
 	}
 
+	var newTimestamp float64
 	for _, data := range events {
 		for _, metricConfig := range selEventConfigs {
 			match := metricConfig.Regex.FindStringSubmatch(data.Event)
 			if match != nil {
-				var newTimestamp float64 = 0
+				newTimestamp = 0.0
 				datetime := data.Date + " " + data.Time
 				t, err := time.Parse(SELDateTimeFormat, datetime)
 				// ignore errors with invalid date or time
@@ -103,7 +103,7 @@ func (c SELEventsCollector) Collect(result freeipmi.Result, ch chan<- prometheus
 				// ID,Date,Time,Name,Type,State,Event
 				// 3,PostInit,PostInit,Sensor #211,Memory,Warning,Correctable memory error ; Event Data3 = 34h
 				if err != nil {
-					level.Debug(logger).Log("msg", "Failed to parse time", "target", targetName(target.host), "error", err)
+					logger.Debug("Failed to parse time", "target", targetName(target.host), "error", err)
 				} else {
 					newTimestamp = float64(t.Unix())
 				}
